/**********************************************************************************************************************					
Instituto Nacional de Estadstica (INE) www.ine.es					
***********************************************************************************************************************					
					
DESCRIPCIN:					
Este programa genera un fichero SAS con formatos, partiendo de un fichero sin ellos.					
					
Consta de las siguientes partes:					
	* 1. Definir la librera de trabajo --> Libname				
	* 2. Definicin de formatos --> PROC FORMAT				
	* 3. Vincular formatos a la base de datos --> PASO data				
					
 Entrada:                                                           					
     - Fichero SAS sin formatos: 	 EMIDE_2014.sas7bdat				
 Salida:                                                           					
     - Fichero SAS con formatos: 	 EMIDE_2014_conFormato.sas7bdat				
					
Donde:					
	* Operacin: EMIDE Encuesta sobre movilidad internacional de los estudiantes				
	* Periodo: 2014				
					
************************************************************************************************************************/					
					
/*1) Definir la librera de trabajo: introducir el directorio que desee como librera					
(se da como ejemplo 'C:\Mis resultados'), y copiar en ese directorio el fichero sas "EMIDE_2014.sas7bdat"*/					
					
libname ROutput 'C:\Mis resultados';					
options fmtsearch = (ROutput ROutput.cat1);

* 2) DEFINICIN DE FORMATOS;
PROC FORMAT LIBRARY=ROutput.cat1;
	value $T_SEXO												
												
"1"="Hombre"												
"6"="Mujer"												
;												
value $T_EDAD												
												
"1"="Entre 18 y 24 aos cumplidos"												
"2"="Entre 25 y 29 aos cumplidos"												
"3"="Entre 30 y 34 aos cumplidos"												
;												
value $T_PAIS												
												
"126"="Alemania"												
"103"="Blgica"												
"107"="Dinamarca"												
"109"="Finlandia"												
"110"="Francia"												
"113"="Irlanda"												
"115"="Italia"												
"121"="Pases Bajos"												
"122"="Polonia"												
"123"="Portugal"												
"125"="Reino Unido"												
"131"="Suecia"												
"159"="Otros pases de la Unin Europea"												
"199"="Otros pases de Europa"												
"302"="Estados Unidos"												
"399"="Otros pases de Amrica"												
"200"="frica"												
"400"="Asia"												
"500"="Oceana"												
""="No procede"												
;												
value $T_MOVIL												
												
"1"="Realizar en el extranjero todos los cursos correspondientes a esa titulacin/ estudios."												
"2"="Realizar en el extranjero slo una parte de esa titulacin/estudios."												
"3"="No"												
""="No procede"												
;												
value $T_2SINO												
												
"1"="S"												
"2"="No"												
;												
value $T_6SINO												
												
"1"="S"												
"6"="No"												
""="No procede"												
;												
value $T_DURAC												
												
"1"="Ms de un ao"												
"2"="Ms de 6 meses y hasta un ao"												
"3"="De 3 a 6 meses"												
"4"="Dos semanas o ms pero menos de 3 meses"												
"5"="Una semana o ms pero menos de 2 semanas"												
"6"="Menos de una semana"												
""="No procede"												
;												
value $T_PROV												
												
"02"="Albacete"												
"03"="Alicante/Alacant"												
"04"="Almera"												
"01"="Araba/lava"												
"33"="Asturias"												
"05"="vila"												
"06"="Badajoz"												
"07"="Balears, Illes"												
"08"="Barcelona"												
"48"="Bizkaia"												
"09"="Burgos"												
"10"="Cceres"												
"11"="Cdiz"												
"39"="Cantabria"												
"12"="Castelln/Castell"												
"13"="Ciudad Real"												
"14"="Crdoba"												
"15"="Corua, A"												
"16"="Cuenca"												
"20"="Gipuzkoa"												
"17"="Girona"												
"18"="Granada"												
"19"="Guadalajara"												
"21"="Huelva"												
"22"="Huesca"												
"23"="Jan"												
"24"="Len"												
"25"="Lleida"												
"27"="Lugo"												
"28"="Madrid"												
"29"="Mlaga"												
"30"="Murcia"												
"31"="Navarra"												
"32"="Ourense"												
"34"="Palencia"												
"35"="Palmas, Las"												
"36"="Pontevedra"												
"26"="Rioja, La"												
"37"="Salamanca"												
"38"="Santa Cruz de Tenerife"												
"40"="Segovia"												
"41"="Sevilla"												
"42"="Soria"												
"43"="Tarragona"												
"44"="Teruel"												
"45"="Toledo"												
"46"="Valencia/Valncia"												
"47"="Valladolid"												
"49"="Zamora"												
"50"="Zaragoza"												
"51"="Ceuta"												
"52"="Melilla"												
;												



* 3) VINCULAR FORMATOS A LA BASE DE DATOS;
data ROutput.EMIDE_2014_ConFormato;
	set ROutput.EMIDE_2014;

FORMAT PROV $T_PROV.;
FORMAT SEXO $T_SEXO.;
FORMAT G_EDAD $T_EDAD.;
FORMAT TITU11 $T_6SINO.;
FORMAT ESTU11 $T_6SINO.;
FORMAT MOV11 $T_MOVIL.;
FORMAT DUR11 $T_DURAC.;
FORMAT PAI11 $T_PAIS.;
FORMAT TITU12 $T_6SINO.;
FORMAT ESTU12 $T_6SINO.;
FORMAT MOV12 $T_MOVIL.;
FORMAT DUR12 $T_DURAC.;
FORMAT PAI12 $T_PAIS.;
FORMAT TITU13 $T_6SINO.;
FORMAT ESTU13 $T_6SINO.;
FORMAT MOV13 $T_MOVIL.;
FORMAT DUR13 $T_DURAC.;
FORMAT PAI13 $T_PAIS.;
FORMAT TITU21 $T_6SINO.;
FORMAT MOV21T $T_MOVIL.;
FORMAT DUR21T $T_DURAC.;
FORMAT PAI21T $T_PAIS.;
FORMAT ESTU21 $T_6SINO.;
FORMAT MOV21E $T_MOVIL.;
FORMAT DUR21E $T_DURAC.;
FORMAT PAI21E $T_PAIS.;
FORMAT TITU22 $T_6SINO.;
FORMAT MOV22T $T_MOVIL.;
FORMAT DUR22T $T_DURAC.;
FORMAT PAI22T $T_PAIS.;
FORMAT ESTU22 $T_6SINO.;
FORMAT MOV22E $T_MOVIL.;
FORMAT DUR22E $T_DURAC.;
FORMAT PAI22E $T_PAIS.;
FORMAT TITU23 $T_6SINO.;
FORMAT MOV23T $T_MOVIL.;
FORMAT DUR23T $T_DURAC.;
FORMAT PAI23T $T_PAIS.;
FORMAT ESTU23 $T_6SINO.;
FORMAT MOV23E $T_MOVIL.;
FORMAT DUR23E $T_DURAC.;
FORMAT PAI23E $T_PAIS.;
FORMAT TITU24 $T_6SINO.;
FORMAT MOV24T $T_MOVIL.;
FORMAT DUR24T $T_DURAC.;
FORMAT PAI24T $T_PAIS.;
FORMAT ESTU24 $T_6SINO.;
FORMAT MOV24E $T_MOVIL.;
FORMAT DUR24E $T_DURAC.;
FORMAT PAI24E $T_PAIS.;
FORMAT TITU25 $T_6SINO.;
FORMAT MOV25T $T_MOVIL.;
FORMAT DUR25T $T_DURAC.;
FORMAT PAI25T $T_PAIS.;
FORMAT ESTU25 $T_6SINO.;
FORMAT MOV25E $T_MOVIL.;
FORMAT DUR25E $T_DURAC.;
FORMAT PAI25E $T_PAIS.;
FORMAT TITU26 $T_6SINO.;
FORMAT MOV26T $T_MOVIL.;
FORMAT DUR26T $T_DURAC.;
FORMAT PAI26T $T_PAIS.;
FORMAT ESTU26 $T_6SINO.;
FORMAT MOV26E $T_MOVIL.;
FORMAT DUR26E $T_DURAC.;
FORMAT PAI26E $T_PAIS.;
FORMAT TITU27 $T_6SINO.;
FORMAT MOV27T $T_MOVIL.;
FORMAT DUR27T $T_DURAC.;
FORMAT PAI27T $T_PAIS.;
FORMAT ESTU27 $T_6SINO.;
FORMAT MOV27E $T_MOVIL.;
FORMAT DUR27E $T_DURAC.;
FORMAT PAI27E $T_PAIS.;
FORMAT MOV31 $T_2SINO.;
FORMAT DUR31 $T_DURAC.;
FORMAT PAI31 $T_PAIS.;
FORMAT MOV32 $T_2SINO.;
FORMAT DUR32 $T_DURAC.;
FORMAT PAI32 $T_PAIS.;
FORMAT MOV33 $T_2SINO.;
FORMAT DUR33 $T_DURAC.;
FORMAT PAI33 $T_PAIS.;



RUN;
/* FIN PROGRAMA: Microdatos en SAS: EMIDE_2014.sas*/
